@@ -4,11 +4,12 @@ use 5.006;
 use strict;
 use Sys::Hostname;
 use IO::Select;
+use IO::Handle;
 use Carp;
 
 use constant HOSTNAME => hostname();
 
-$Net::Server::Mail::VERSION = '0.01';
+$Net::Server::Mail::VERSION = '0.03';
 
 =pod
 
@@ -72,10 +73,25 @@ Net::Server::Mail - Class to easily create a mail server
 
 =head1 DESCRIPTION
 
-This class is the base class for mail service protocols such as
+This module is a versatile and extensible implementation of the SMTP
+protocol and its different evolutions like ESMTP and LMTP. The event
+driven object-oriented API makes easy to incorporate the SMTP protocol
+to your programs.
+
+Other SMTPd implementations don't support useful ESMTP extensions and
+the LMTP protocol. Their interface design precludes adding them
+later. So I've decided to rewrite a complete implementation with
+extensibility in mind.
+
+It provides mechanism to easy addition future or not yet implemented
+ESMTP extensions. Developers can hook code at each SMTP session state
+and change the module's behaviors by registering event call-backs. The
+class is designed to be easily inherited from.
+
+This class is the base class for mail service protocols such axs
 B<Net::Server::Mail::SMTP>, B<Net::Server::Mail::ESMTP> and
-B<Net::Server::Mail::LMTP>. Refer to the documentation provided
-with each of these modules.
+B<Net::Server::Mail::LMTP>. Refer to the documentation provided with
+each of these modules.
 
 =head1 METHODS
 
@@ -145,8 +161,24 @@ sub init
 
     if(defined $options->{handle_in} && defined $options->{handle_out})
     {
-        $self->{in}  = $options->{handle_in};
-        $self->{out} = $options->{handle_out};
+        if(ref $options->{handle_in} eq 'IO::Handle')
+        {
+            $self->{in} = $options->{handle_in};
+        }
+        else
+        {
+            $self->{in} = 
+              IO::Handle->new->fdopen(fileno($options->{handle_in}), "r");
+        }
+        if(ref $options->{handle_out} eq 'IO::Handle')
+        {
+            $self->{out} = $options->{handle_out};
+        }
+        else
+        {
+            $self->{out} = 
+              IO::Handle->new->fdopen(fileno($options->{handle_out}), "w");
+        }
     }
     elsif(defined $options->{'socket'})
     {
@@ -155,8 +187,8 @@ sub init
     }
     else
     {
-        $self->{in}  = \*STDIN;
-        $self->{out} = \*STDOUT;
+        $self->{in}  = IO::Handle->new->fdopen(fileno(STDIN), "r");
+        $self->{out} = IO::Handle->new->fdopen(fileno(STDOUT), "w");
     }
 
     $self->{process_operation} = \&process_operation;
